/**
 * Encodes a string in base64 format.
 * @param value - The string to encode.
 */
export declare function encode(value: string): string;
/**
 * Decodes a base64 string into a regular string.
 * @param value - The base64 string to decode.
 */
export declare function decode(value: string): string;
//# sourceMappingURL=base64.d.ts.map