import { PipelinePolicy } from "@azure/core-rest-pipeline";
type MetadataLevel = "none" | "minimal";
/**
 * A policy factory for setting the Accept header to ignore odata metadata
 * @internal
 */
export declare function createOdataMetadataPolicy(metadataLevel: MetadataLevel): PipelinePolicy;
export {};
//# sourceMappingURL=odataMetadataPolicy.d.ts.map