// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
export { AzureKeyCredential } from "@azure/core-auth";
export { KnownSemanticErrorMode, KnownSemanticErrorReason, KnownSemanticSearchResultsType, KnownVectorFilterMode, KnownVectorQueryKind, } from "./generated/data/models/index.js";
export { KnownAzureOpenAIModelName, KnownBlobIndexerDataToExtract, KnownBlobIndexerImageAction, KnownBlobIndexerPDFTextRotationAlgorithm, KnownBlobIndexerParsingMode, KnownCharFilterName as KnownCharFilterNames, KnownCustomEntityLookupSkillLanguage, KnownDocumentIntelligenceLayoutSkillChunkingUnit, KnownDocumentIntelligenceLayoutSkillExtractionOptions, KnownDocumentIntelligenceLayoutSkillMarkdownHeaderDepth, KnownDocumentIntelligenceLayoutSkillOutputFormat, KnownDocumentIntelligenceLayoutSkillOutputMode, KnownEntityCategory, KnownEntityRecognitionSkillLanguage, KnownImageAnalysisSkillLanguage, KnownImageDetail, KnownIndexProjectionMode, KnownIndexerExecutionEnvironment, KnownKeyPhraseExtractionSkillLanguage, KnownLexicalNormalizerName as KnownLexicalNormalizerNames, KnownLexicalTokenizerName as KnownTokenizerNames, KnownOcrLineEnding, KnownOcrSkillLanguage, KnownPIIDetectionSkillMaskingMode, KnownRankingOrder, KnownRegexFlags, KnownSearchFieldDataType, KnownSearchIndexerDataSourceType, KnownSentimentSkillLanguage, KnownSplitSkillLanguage, KnownTextSplitMode, KnownTextTranslationSkillLanguage, KnownTokenFilterName as KnownTokenFilterNames, KnownVectorEncodingFormat, KnownVectorSearchAlgorithmKind, KnownVectorSearchAlgorithmMetric, KnownVectorSearchCompressionKind, KnownVectorSearchCompressionRescoreStorageMethod, KnownVectorSearchCompressionTarget, KnownVectorSearchVectorizerKind, KnownVisualFeature, } from "./generated/service/models/index.js";
export { default as GeographyPoint } from "./geographyPoint.js";
export { IndexDocumentsBatch } from "./indexDocumentsBatch.js";
export { odata } from "./odata.js";
export { KnownSearchAudience } from "./searchAudience.js";
export { SearchClient } from "./searchClient.js";
export { SearchIndexClient } from "./searchIndexClient.js";
export { SearchIndexerClient } from "./searchIndexerClient.js";
export { DEFAULT_BATCH_SIZE, DEFAULT_FLUSH_WINDOW, DEFAULT_RETRY_COUNT, SearchIndexingBufferedSender, } from "./searchIndexingBufferedSender.js";
export { KnownAnalyzerNames, } from "./serviceModels.js";
export { createSynonymMapFromFile } from "./synonymMapHelper.js";
//# sourceMappingURL=index.js.map