/**
 * Represents a geographic point in global coordinates.
 */
export default class GeographyPoint {
    /**
     * The latitude in decimal.
     */
    latitude: number;
    /**
     * The longitude in decimal.
     */
    longitude: number;
    /**
     * Constructs a new instance of GeographyPoint given
     * the specified coordinates.
     * @param geographyPoint - object with longitude and latitude values in decimal
     */
    constructor(geographyPoint: {
        longitude: number;
        latitude: number;
    });
    /**
     * Used to serialize to a GeoJSON Point.
     */
    toJSON(): Record<string, unknown>;
}
//# sourceMappingURL=geographyPoint.d.ts.map