import { SynonymMap } from "./serviceModels.js";
/**
 * Helper method to create a SynonymMap object. This is a NodeJS only method.
 * Will throw an error for browser.
 *
 * @param _name - Name of the SynonymMap.
 * @param _filePath - Path of the file that contains the Synonyms (seperated by new lines)
 * @returns SynonymMap object
 */
export declare function createSynonymMapFromFile(_name: string, _filePath: string): Promise<SynonymMap>;
//# sourceMappingURL=synonymMapHelper-browser.d.mts.map