import * as coreClient from "@azure/core-client";
export declare const SearchIndexerDataSource: coreClient.CompositeMapper;
export declare const DataSourceCredentials: coreClient.CompositeMapper;
export declare const SearchIndexerDataContainer: coreClient.CompositeMapper;
export declare const DataChangeDetectionPolicy: coreClient.CompositeMapper;
export declare const DataDeletionDetectionPolicy: coreClient.CompositeMapper;
export declare const SearchResourceEncryptionKey: coreClient.CompositeMapper;
export declare const AzureActiveDirectoryApplicationCredentials: coreClient.CompositeMapper;
export declare const ErrorResponse: coreClient.CompositeMapper;
export declare const ErrorDetail: coreClient.CompositeMapper;
export declare const ErrorAdditionalInfo: coreClient.CompositeMapper;
export declare const ListDataSourcesResult: coreClient.CompositeMapper;
export declare const SearchIndexer: coreClient.CompositeMapper;
export declare const IndexingSchedule: coreClient.CompositeMapper;
export declare const IndexingParameters: coreClient.CompositeMapper;
export declare const IndexingParametersConfiguration: coreClient.CompositeMapper;
export declare const FieldMapping: coreClient.CompositeMapper;
export declare const FieldMappingFunction: coreClient.CompositeMapper;
export declare const ListIndexersResult: coreClient.CompositeMapper;
export declare const SearchIndexerStatus: coreClient.CompositeMapper;
export declare const IndexerExecutionResult: coreClient.CompositeMapper;
export declare const SearchIndexerError: coreClient.CompositeMapper;
export declare const SearchIndexerWarning: coreClient.CompositeMapper;
export declare const SearchIndexerLimits: coreClient.CompositeMapper;
export declare const SearchIndexerSkillset: coreClient.CompositeMapper;
export declare const SearchIndexerSkill: coreClient.CompositeMapper;
export declare const InputFieldMappingEntry: coreClient.CompositeMapper;
export declare const OutputFieldMappingEntry: coreClient.CompositeMapper;
export declare const CognitiveServicesAccount: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStore: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStoreProjection: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStoreProjectionSelector: coreClient.CompositeMapper;
export declare const SearchIndexerIndexProjection: coreClient.CompositeMapper;
export declare const SearchIndexerIndexProjectionSelector: coreClient.CompositeMapper;
export declare const SearchIndexerIndexProjectionParameters: coreClient.CompositeMapper;
export declare const ListSkillsetsResult: coreClient.CompositeMapper;
export declare const SynonymMap: coreClient.CompositeMapper;
export declare const ListSynonymMapsResult: coreClient.CompositeMapper;
export declare const SearchIndex: coreClient.CompositeMapper;
export declare const SearchField: coreClient.CompositeMapper;
export declare const ScoringProfile: coreClient.CompositeMapper;
export declare const TextWeights: coreClient.CompositeMapper;
export declare const ScoringFunction: coreClient.CompositeMapper;
export declare const CorsOptions: coreClient.CompositeMapper;
export declare const Suggester: coreClient.CompositeMapper;
export declare const LexicalAnalyzer: coreClient.CompositeMapper;
export declare const LexicalTokenizer: coreClient.CompositeMapper;
export declare const TokenFilter: coreClient.CompositeMapper;
export declare const CharFilter: coreClient.CompositeMapper;
export declare const BaseLexicalNormalizer: coreClient.CompositeMapper;
export declare const Similarity: coreClient.CompositeMapper;
export declare const SemanticSearch: coreClient.CompositeMapper;
export declare const SemanticConfiguration: coreClient.CompositeMapper;
export declare const SemanticPrioritizedFields: coreClient.CompositeMapper;
export declare const SemanticField: coreClient.CompositeMapper;
export declare const VectorSearch: coreClient.CompositeMapper;
export declare const VectorSearchProfile: coreClient.CompositeMapper;
export declare const VectorSearchAlgorithmConfiguration: coreClient.CompositeMapper;
export declare const VectorSearchVectorizer: coreClient.CompositeMapper;
export declare const VectorSearchCompression: coreClient.CompositeMapper;
export declare const RescoringOptions: coreClient.CompositeMapper;
export declare const ListIndexesResult: coreClient.CompositeMapper;
export declare const GetIndexStatisticsResult: coreClient.CompositeMapper;
export declare const AnalyzeRequest: coreClient.CompositeMapper;
export declare const AnalyzeResult: coreClient.CompositeMapper;
export declare const AnalyzedTokenInfo: coreClient.CompositeMapper;
export declare const ServiceStatistics: coreClient.CompositeMapper;
export declare const ServiceCounters: coreClient.CompositeMapper;
export declare const ResourceCounter: coreClient.CompositeMapper;
export declare const ServiceLimits: coreClient.CompositeMapper;
export declare const HnswParameters: coreClient.CompositeMapper;
export declare const ExhaustiveKnnParameters: coreClient.CompositeMapper;
export declare const ScalarQuantizationParameters: coreClient.CompositeMapper;
export declare const AzureOpenAIParameters: coreClient.CompositeMapper;
export declare const SearchIndexerDataIdentity: coreClient.CompositeMapper;
export declare const WebApiParameters: coreClient.CompositeMapper;
export declare const DistanceScoringParameters: coreClient.CompositeMapper;
export declare const FreshnessScoringParameters: coreClient.CompositeMapper;
export declare const MagnitudeScoringParameters: coreClient.CompositeMapper;
export declare const TagScoringParameters: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStoreParameters: coreClient.CompositeMapper;
export declare const CustomEntity: coreClient.CompositeMapper;
export declare const CustomEntityAlias: coreClient.CompositeMapper;
export declare const DocumentIntelligenceLayoutSkillChunkingProperties: coreClient.CompositeMapper;
export declare const HighWaterMarkChangeDetectionPolicy: coreClient.CompositeMapper;
export declare const SqlIntegratedChangeTrackingPolicy: coreClient.CompositeMapper;
export declare const SoftDeleteColumnDeletionDetectionPolicy: coreClient.CompositeMapper;
export declare const ConditionalSkill: coreClient.CompositeMapper;
export declare const KeyPhraseExtractionSkill: coreClient.CompositeMapper;
export declare const OcrSkill: coreClient.CompositeMapper;
export declare const ImageAnalysisSkill: coreClient.CompositeMapper;
export declare const LanguageDetectionSkill: coreClient.CompositeMapper;
export declare const ShaperSkill: coreClient.CompositeMapper;
export declare const MergeSkill: coreClient.CompositeMapper;
export declare const EntityRecognitionSkill: coreClient.CompositeMapper;
export declare const SentimentSkill: coreClient.CompositeMapper;
export declare const SentimentSkillV3: coreClient.CompositeMapper;
export declare const EntityLinkingSkill: coreClient.CompositeMapper;
export declare const EntityRecognitionSkillV3: coreClient.CompositeMapper;
export declare const PIIDetectionSkill: coreClient.CompositeMapper;
export declare const SplitSkill: coreClient.CompositeMapper;
export declare const CustomEntityLookupSkill: coreClient.CompositeMapper;
export declare const TextTranslationSkill: coreClient.CompositeMapper;
export declare const DocumentExtractionSkill: coreClient.CompositeMapper;
export declare const DocumentIntelligenceLayoutSkill: coreClient.CompositeMapper;
export declare const WebApiSkill: coreClient.CompositeMapper;
export declare const AzureOpenAIEmbeddingSkill: coreClient.CompositeMapper;
export declare const DefaultCognitiveServicesAccount: coreClient.CompositeMapper;
export declare const CognitiveServicesAccountKey: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStoreTableProjectionSelector: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStoreBlobProjectionSelector: coreClient.CompositeMapper;
export declare const DistanceScoringFunction: coreClient.CompositeMapper;
export declare const FreshnessScoringFunction: coreClient.CompositeMapper;
export declare const MagnitudeScoringFunction: coreClient.CompositeMapper;
export declare const TagScoringFunction: coreClient.CompositeMapper;
export declare const CustomAnalyzer: coreClient.CompositeMapper;
export declare const PatternAnalyzer: coreClient.CompositeMapper;
export declare const LuceneStandardAnalyzer: coreClient.CompositeMapper;
export declare const StopAnalyzer: coreClient.CompositeMapper;
export declare const ClassicTokenizer: coreClient.CompositeMapper;
export declare const EdgeNGramTokenizer: coreClient.CompositeMapper;
export declare const KeywordTokenizer: coreClient.CompositeMapper;
export declare const KeywordTokenizerV2: coreClient.CompositeMapper;
export declare const MicrosoftLanguageTokenizer: coreClient.CompositeMapper;
export declare const MicrosoftLanguageStemmingTokenizer: coreClient.CompositeMapper;
export declare const NGramTokenizer: coreClient.CompositeMapper;
export declare const PathHierarchyTokenizerV2: coreClient.CompositeMapper;
export declare const PatternTokenizer: coreClient.CompositeMapper;
export declare const LuceneStandardTokenizer: coreClient.CompositeMapper;
export declare const LuceneStandardTokenizerV2: coreClient.CompositeMapper;
export declare const UaxUrlEmailTokenizer: coreClient.CompositeMapper;
export declare const AsciiFoldingTokenFilter: coreClient.CompositeMapper;
export declare const CjkBigramTokenFilter: coreClient.CompositeMapper;
export declare const CommonGramTokenFilter: coreClient.CompositeMapper;
export declare const DictionaryDecompounderTokenFilter: coreClient.CompositeMapper;
export declare const EdgeNGramTokenFilter: coreClient.CompositeMapper;
export declare const EdgeNGramTokenFilterV2: coreClient.CompositeMapper;
export declare const ElisionTokenFilter: coreClient.CompositeMapper;
export declare const KeepTokenFilter: coreClient.CompositeMapper;
export declare const KeywordMarkerTokenFilter: coreClient.CompositeMapper;
export declare const LengthTokenFilter: coreClient.CompositeMapper;
export declare const LimitTokenFilter: coreClient.CompositeMapper;
export declare const NGramTokenFilter: coreClient.CompositeMapper;
export declare const NGramTokenFilterV2: coreClient.CompositeMapper;
export declare const PatternCaptureTokenFilter: coreClient.CompositeMapper;
export declare const PatternReplaceTokenFilter: coreClient.CompositeMapper;
export declare const PhoneticTokenFilter: coreClient.CompositeMapper;
export declare const ShingleTokenFilter: coreClient.CompositeMapper;
export declare const SnowballTokenFilter: coreClient.CompositeMapper;
export declare const StemmerTokenFilter: coreClient.CompositeMapper;
export declare const StemmerOverrideTokenFilter: coreClient.CompositeMapper;
export declare const StopwordsTokenFilter: coreClient.CompositeMapper;
export declare const SynonymTokenFilter: coreClient.CompositeMapper;
export declare const TruncateTokenFilter: coreClient.CompositeMapper;
export declare const UniqueTokenFilter: coreClient.CompositeMapper;
export declare const WordDelimiterTokenFilter: coreClient.CompositeMapper;
export declare const MappingCharFilter: coreClient.CompositeMapper;
export declare const PatternReplaceCharFilter: coreClient.CompositeMapper;
export declare const CustomLexicalNormalizer: coreClient.CompositeMapper;
export declare const ClassicSimilarity: coreClient.CompositeMapper;
export declare const BM25Similarity: coreClient.CompositeMapper;
export declare const HnswAlgorithmConfiguration: coreClient.CompositeMapper;
export declare const ExhaustiveKnnAlgorithmConfiguration: coreClient.CompositeMapper;
export declare const AzureOpenAIVectorizer: coreClient.CompositeMapper;
export declare const WebApiVectorizer: coreClient.CompositeMapper;
export declare const ScalarQuantizationCompression: coreClient.CompositeMapper;
export declare const BinaryQuantizationCompression: coreClient.CompositeMapper;
export declare const SearchIndexerDataNoneIdentity: coreClient.CompositeMapper;
export declare const SearchIndexerDataUserAssignedIdentity: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStoreObjectProjectionSelector: coreClient.CompositeMapper;
export declare const SearchIndexerKnowledgeStoreFileProjectionSelector: coreClient.CompositeMapper;
export declare let discriminators: {
    DataChangeDetectionPolicy: coreClient.CompositeMapper;
    DataDeletionDetectionPolicy: coreClient.CompositeMapper;
    SearchIndexerSkill: coreClient.CompositeMapper;
    CognitiveServicesAccount: coreClient.CompositeMapper;
    ScoringFunction: coreClient.CompositeMapper;
    LexicalAnalyzer: coreClient.CompositeMapper;
    LexicalTokenizer: coreClient.CompositeMapper;
    TokenFilter: coreClient.CompositeMapper;
    CharFilter: coreClient.CompositeMapper;
    BaseLexicalNormalizer: coreClient.CompositeMapper;
    Similarity: coreClient.CompositeMapper;
    VectorSearchAlgorithmConfiguration: coreClient.CompositeMapper;
    VectorSearchVectorizer: coreClient.CompositeMapper;
    VectorSearchCompression: coreClient.CompositeMapper;
    SearchIndexerDataIdentity: coreClient.CompositeMapper;
    "DataChangeDetectionPolicy.#Microsoft.Azure.Search.HighWaterMarkChangeDetectionPolicy": coreClient.CompositeMapper;
    "DataChangeDetectionPolicy.#Microsoft.Azure.Search.SqlIntegratedChangeTrackingPolicy": coreClient.CompositeMapper;
    "DataDeletionDetectionPolicy.#Microsoft.Azure.Search.SoftDeleteColumnDeletionDetectionPolicy": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Util.ConditionalSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.KeyPhraseExtractionSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Vision.OcrSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Vision.ImageAnalysisSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.LanguageDetectionSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Util.ShaperSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.MergeSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.EntityRecognitionSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.SentimentSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.V3.SentimentSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.V3.EntityLinkingSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.V3.EntityRecognitionSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.PIIDetectionSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.SplitSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.CustomEntityLookupSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.TranslationSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Util.DocumentExtractionSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Util.DocumentIntelligenceLayoutSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Custom.WebApiSkill": coreClient.CompositeMapper;
    "SearchIndexerSkill.#Microsoft.Skills.Text.AzureOpenAIEmbeddingSkill": coreClient.CompositeMapper;
    "CognitiveServicesAccount.#Microsoft.Azure.Search.DefaultCognitiveServices": coreClient.CompositeMapper;
    "CognitiveServicesAccount.#Microsoft.Azure.Search.CognitiveServicesByKey": coreClient.CompositeMapper;
    "ScoringFunction.distance": coreClient.CompositeMapper;
    "ScoringFunction.freshness": coreClient.CompositeMapper;
    "ScoringFunction.magnitude": coreClient.CompositeMapper;
    "ScoringFunction.tag": coreClient.CompositeMapper;
    "LexicalAnalyzer.#Microsoft.Azure.Search.CustomAnalyzer": coreClient.CompositeMapper;
    "LexicalAnalyzer.#Microsoft.Azure.Search.PatternAnalyzer": coreClient.CompositeMapper;
    "LexicalAnalyzer.#Microsoft.Azure.Search.StandardAnalyzer": coreClient.CompositeMapper;
    "LexicalAnalyzer.#Microsoft.Azure.Search.StopAnalyzer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.ClassicTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.EdgeNGramTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.KeywordTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.KeywordTokenizerV2": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.MicrosoftLanguageTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.MicrosoftLanguageStemmingTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.NGramTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.PathHierarchyTokenizerV2": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.PatternTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.StandardTokenizer": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.StandardTokenizerV2": coreClient.CompositeMapper;
    "LexicalTokenizer.#Microsoft.Azure.Search.UaxUrlEmailTokenizer": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.AsciiFoldingTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.CjkBigramTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.CommonGramTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.DictionaryDecompounderTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.EdgeNGramTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.EdgeNGramTokenFilterV2": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.ElisionTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.KeepTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.KeywordMarkerTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.LengthTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.LimitTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.NGramTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.NGramTokenFilterV2": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.PatternCaptureTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.PatternReplaceTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.PhoneticTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.ShingleTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.SnowballTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.StemmerTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.StemmerOverrideTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.StopwordsTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.SynonymTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.TruncateTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.UniqueTokenFilter": coreClient.CompositeMapper;
    "TokenFilter.#Microsoft.Azure.Search.WordDelimiterTokenFilter": coreClient.CompositeMapper;
    "CharFilter.#Microsoft.Azure.Search.MappingCharFilter": coreClient.CompositeMapper;
    "CharFilter.#Microsoft.Azure.Search.PatternReplaceCharFilter": coreClient.CompositeMapper;
    "BaseLexicalNormalizer.#Microsoft.Azure.Search.CustomNormalizer": coreClient.CompositeMapper;
    "Similarity.#Microsoft.Azure.Search.ClassicSimilarity": coreClient.CompositeMapper;
    "Similarity.#Microsoft.Azure.Search.BM25Similarity": coreClient.CompositeMapper;
    "VectorSearchAlgorithmConfiguration.hnsw": coreClient.CompositeMapper;
    "VectorSearchAlgorithmConfiguration.exhaustiveKnn": coreClient.CompositeMapper;
    "VectorSearchVectorizer.azureOpenAI": coreClient.CompositeMapper;
    "VectorSearchVectorizer.customWebApi": coreClient.CompositeMapper;
    "VectorSearchCompression.scalarQuantization": coreClient.CompositeMapper;
    "VectorSearchCompression.binaryQuantization": coreClient.CompositeMapper;
    "SearchIndexerDataIdentity.#Microsoft.Azure.Search.DataNoneIdentity": coreClient.CompositeMapper;
    "SearchIndexerDataIdentity.#Microsoft.Azure.Search.DataUserAssignedIdentity": coreClient.CompositeMapper;
};
//# sourceMappingURL=mappers.d.ts.map