/**
 * Known values for Search Audience
 */
export declare enum KnownSearchAudience {
    /**
     * Audience for Azure China
     */
    AzureChina = "https://search.azure.cn",
    /**
     * Audience for Azure Government
     */
    AzureGovernment = "https://search.azure.us",
    /**
     * Audience for Azure Public
     */
    AzurePublicCloud = "https://search.azure.com"
}
//# sourceMappingURL=searchAudience.d.ts.map