import * as coreHttpCompat from "@azure/core-http-compat";
import { Documents } from "./operationsInterfaces/index.js";
import { ApiVersion20250901, SearchClientOptionalParams } from "./models/index.js";
/** @internal */
export declare class SearchClient extends coreHttpCompat.ExtendedServiceClient {
    endpoint: string;
    indexName: string;
    apiVersion: ApiVersion20250901;
    /**
     * Initializes a new instance of the SearchClient class.
     * @param endpoint The endpoint URL of the search service.
     * @param indexName The name of the index.
     * @param apiVersion Api Version
     * @param options The parameter options
     */
    constructor(endpoint: string, indexName: string, apiVersion: ApiVersion20250901, options?: SearchClientOptionalParams);
    /** A function that adds a policy that sets the api-version (or equivalent) to reflect the library version. */
    private addCustomApiVersionPolicy;
    documents: Documents;
}
//# sourceMappingURL=searchClient.d.ts.map