import { KeyCredential } from "@azure/core-auth";
import { PipelinePolicy } from "@azure/core-rest-pipeline";
/**
 * Create an HTTP pipeline policy to authenticate a request
 * using an `AzureKeyCredential` for Azure Cognitive Search
 */
export declare function createSearchApiKeyCredentialPolicy(credential: KeyCredential): PipelinePolicy;
//# sourceMappingURL=searchApiKeyCredentialPolicy.d.ts.map