"use strict";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.encode = encode;
exports.decode = decode;
/**
 * Encodes a string in base64 format.
 * @param value - The string to encode.
 */
function encode(value) {
    return Buffer.from(value).toString("base64");
}
/**
 * Decodes a base64 string into a regular string.
 * @param value - The base64 string to decode.
 */
function decode(value) {
    return Buffer.from(value, "base64").toString();
}
//# sourceMappingURL=base64.js.map