export declare const createSpan: <Options extends {
    tracingOptions?: import("@azure/core-tracing").OperationTracingOptions;
}>(name: string, operationOptions?: Options, spanOptions?: import("@azure/core-tracing").TracingSpanOptions) => {
    span: import("@azure/core-tracing").TracingSpan;
    updatedOptions: import("@azure/core-tracing").OptionsWithTracingContext<Options>;
};
//# sourceMappingURL=tracing.d.ts.map