"use strict";
/*
 * Copyright (c) Microsoft Corporation.
 * Licensed under the MIT License.
 *
 * Code generated by Microsoft (R) AutoRest Code Generator.
 * Changes may cause incorrect behavior and will be lost if the code is regenerated.
 */
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
tslib_1.__exportStar(require("./dataSources.js"), exports);
tslib_1.__exportStar(require("./indexers.js"), exports);
tslib_1.__exportStar(require("./skillsets.js"), exports);
tslib_1.__exportStar(require("./synonymMaps.js"), exports);
tslib_1.__exportStar(require("./indexes.js"), exports);
//# sourceMappingURL=index.js.map