import { OperationParameter, OperationURLParameter, OperationQueryParameter } from "@azure/core-client";
export declare const accept: OperationParameter;
export declare const endpoint: OperationURLParameter;
export declare const indexName: OperationURLParameter;
export declare const apiVersion: OperationQueryParameter;
export declare const searchText: OperationQueryParameter;
export declare const includeTotalResultCount: OperationQueryParameter;
export declare const facets: OperationQueryParameter;
export declare const filter: OperationQueryParameter;
export declare const highlightFields: OperationQueryParameter;
export declare const highlightPostTag: OperationQueryParameter;
export declare const highlightPreTag: OperationQueryParameter;
export declare const minimumCoverage: OperationQueryParameter;
export declare const orderBy: OperationQueryParameter;
export declare const queryType: OperationQueryParameter;
export declare const scoringParameters: OperationQueryParameter;
export declare const scoringProfile: OperationQueryParameter;
export declare const searchFields: OperationQueryParameter;
export declare const searchMode: OperationQueryParameter;
export declare const scoringStatistics: OperationQueryParameter;
export declare const sessionId: OperationQueryParameter;
export declare const select: OperationQueryParameter;
export declare const skip: OperationQueryParameter;
export declare const top: OperationQueryParameter;
export declare const semanticConfiguration: OperationQueryParameter;
export declare const semanticErrorHandling: OperationQueryParameter;
export declare const semanticMaxWaitInMilliseconds: OperationQueryParameter;
export declare const answers: OperationQueryParameter;
export declare const captions: OperationQueryParameter;
export declare const semanticQuery: OperationQueryParameter;
export declare const debug: OperationQueryParameter;
export declare const contentType: OperationParameter;
export declare const searchRequest: OperationParameter;
export declare const key: OperationURLParameter;
export declare const selectedFields: OperationQueryParameter;
export declare const searchText1: OperationQueryParameter;
export declare const suggesterName: OperationQueryParameter;
export declare const filter1: OperationQueryParameter;
export declare const useFuzzyMatching: OperationQueryParameter;
export declare const highlightPostTag1: OperationQueryParameter;
export declare const highlightPreTag1: OperationQueryParameter;
export declare const minimumCoverage1: OperationQueryParameter;
export declare const orderBy1: OperationQueryParameter;
export declare const searchFields1: OperationQueryParameter;
export declare const select1: OperationQueryParameter;
export declare const top1: OperationQueryParameter;
export declare const suggestRequest: OperationParameter;
export declare const batch: OperationParameter;
export declare const autocompleteMode: OperationQueryParameter;
export declare const filter2: OperationQueryParameter;
export declare const useFuzzyMatching1: OperationQueryParameter;
export declare const highlightPostTag2: OperationQueryParameter;
export declare const highlightPreTag2: OperationQueryParameter;
export declare const minimumCoverage2: OperationQueryParameter;
export declare const searchFields2: OperationQueryParameter;
export declare const top2: OperationQueryParameter;
export declare const autocompleteRequest: OperationParameter;
//# sourceMappingURL=parameters.d.ts.map