import { SearchResult as GeneratedSearchResult, SuggestDocumentsResult as GeneratedSuggestDocumentsResult } from "./generated/data/models/index.js";
import { CognitiveServicesAccountUnion, DataChangeDetectionPolicyUnion, DataDeletionDetectionPolicyUnion, SearchField as GeneratedSearchField, SearchIndex as GeneratedSearchIndex, SearchIndexer as GeneratedSearchIndexer, SearchIndexerDataIdentityUnion, SearchIndexerDataSource as GeneratedSearchIndexerDataSourceConnection, SearchIndexerSkillset as GeneratedSearchIndexerSkillset, SearchIndexerSkillUnion, SimilarityUnion, SynonymMap as GeneratedSynonymMap, TokenFilterUnion, VectorSearch as GeneratedVectorSearch, VectorSearchAlgorithmConfigurationUnion as GeneratedVectorSearchAlgorithmConfiguration, VectorSearchVectorizerUnion as GeneratedVectorSearchVectorizer } from "./generated/service/models/index.js";
import { SearchResult, SelectFields, SuggestDocumentsResult } from "./indexModels.js";
import { CognitiveServicesAccount, DataChangeDetectionPolicy, DataDeletionDetectionPolicy, SearchField, SearchIndex, SearchIndexer, SearchIndexerDataIdentity, SearchIndexerDataSourceConnection, SearchIndexerSkill, SearchIndexerSkillset, SimilarityAlgorithm, SynonymMap, TokenFilter, VectorSearch, VectorSearchAlgorithmConfiguration, VectorSearchVectorizer } from "./serviceModels.js";
export declare const defaultServiceVersion = "2025-09-01";
export declare function convertSkillsToPublic(skills: SearchIndexerSkillUnion[]): SearchIndexerSkill[];
export declare function convertCognitiveServicesAccountToGenerated(cognitiveServicesAccount?: CognitiveServicesAccount): CognitiveServicesAccountUnion | undefined;
export declare function convertCognitiveServicesAccountToPublic(cognitiveServicesAccount?: CognitiveServicesAccountUnion): CognitiveServicesAccount | undefined;
export declare function convertTokenFiltersToGenerated(tokenFilters?: TokenFilter[]): TokenFilterUnion[] | undefined;
export declare function convertFieldsToPublic(fields: GeneratedSearchField[]): SearchField[];
export declare function convertFieldsToGenerated(fields: SearchField[]): GeneratedSearchField[];
export declare function convertSimilarityToGenerated(similarity?: SimilarityAlgorithm): SimilarityUnion | undefined;
export declare function convertSimilarityToPublic(similarity?: SimilarityUnion): SimilarityAlgorithm | undefined;
export declare function generatedIndexToPublicIndex(generatedIndex: GeneratedSearchIndex): SearchIndex;
export declare function generatedVectorSearchVectorizerToPublicVectorizer(): undefined;
export declare function generatedVectorSearchVectorizerToPublicVectorizer(generatedVectorizer: GeneratedVectorSearchVectorizer): VectorSearchVectorizer;
export declare function generatedVectorSearchAlgorithmConfigurationToPublicVectorSearchAlgorithmConfiguration(): undefined;
export declare function generatedVectorSearchAlgorithmConfigurationToPublicVectorSearchAlgorithmConfiguration(generatedAlgorithmConfiguration: GeneratedVectorSearchAlgorithmConfiguration): VectorSearchAlgorithmConfiguration;
export declare function generatedVectorSearchToPublicVectorSearch(vectorSearch?: GeneratedVectorSearch): VectorSearch | undefined;
export declare function generatedSearchResultToPublicSearchResult<TModel extends object, TFields extends SelectFields<TModel>>(results: GeneratedSearchResult[]): SearchResult<TModel, TFields>[];
export declare function generatedSuggestDocumentsResultToPublicSuggestDocumentsResult<TModel extends object, TFields extends SelectFields<TModel>>(searchDocumentsResult: GeneratedSuggestDocumentsResult): SuggestDocumentsResult<TModel, TFields>;
export declare function publicIndexToGeneratedIndex(index: SearchIndex): GeneratedSearchIndex;
export declare function generatedSkillsetToPublicSkillset(generatedSkillset: GeneratedSearchIndexerSkillset): SearchIndexerSkillset;
export declare function publicSkillsetToGeneratedSkillset(skillset: SearchIndexerSkillset): GeneratedSearchIndexerSkillset;
export declare function generatedSynonymMapToPublicSynonymMap(synonymMap: GeneratedSynonymMap): SynonymMap;
export declare function publicSynonymMapToGeneratedSynonymMap(synonymMap: SynonymMap): GeneratedSynonymMap;
export declare function publicSearchIndexerToGeneratedSearchIndexer(indexer: SearchIndexer): GeneratedSearchIndexer;
export declare function generatedSearchIndexerToPublicSearchIndexer(indexer: GeneratedSearchIndexer): SearchIndexer;
export declare function publicDataSourceToGeneratedDataSource(dataSource: SearchIndexerDataSourceConnection): GeneratedSearchIndexerDataSourceConnection;
export declare function generatedDataSourceToPublicDataSource(dataSource: GeneratedSearchIndexerDataSourceConnection): SearchIndexerDataSourceConnection;
export declare function convertSearchIndexerDataIdentityToPublic(searchIndexerDataIdentity?: SearchIndexerDataIdentityUnion): SearchIndexerDataIdentity | undefined;
export declare function convertDataChangeDetectionPolicyToPublic(dataChangeDetectionPolicy?: DataChangeDetectionPolicyUnion): DataChangeDetectionPolicy | undefined;
export declare function convertDataDeletionDetectionPolicyToPublic(dataDeletionDetectionPolicy?: DataDeletionDetectionPolicyUnion): DataDeletionDetectionPolicy | undefined;
export declare function getRandomIntegerInclusive(min: number, max: number): number;
//# sourceMappingURL=serviceUtils.d.ts.map